@@ -4,6 +4,3 @@
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
 #undef HAVE_LIBSM
-
-#undef LPC_COMMAND
-#undef LPSTAT_COMMAND
