@@ -66,10 +66,14 @@ print_page (GnomePrintContext *context,
 	    FaxPage *gray_page)
 {
   gchar *page_name;
+  GnomeFont *def_font;
   double *matrix, scale_x, scale_y;
 
+  def_font = gnome_font_new_closest  ("times", GNOME_FONT_BOOK, 0, 10);
+
   page_name = g_strdup_printf ("%d", gray_page->nbr + 1);
   gnome_print_beginpage (context, page_name);
+  gnome_print_setfont (context, def_font);
 
   matrix = create_matrix_from_page (gray_page);
 
@@ -89,6 +93,7 @@ print_page (GnomePrintContext *context,
 
   g_free (matrix);
   g_free (page_name);
+  gnome_font_unref (def_font);
 }
 
 static gboolean
@@ -179,7 +184,6 @@ prepare_print_master (GtkWidget *print_dlg,
 {
   GnomePrintContext *print_context;
   GnomePrintMaster *print_master;
-  GnomeFont *def_font;
   gint copies, collate, range, aborted;
   gint from, to;
   GfvProgressData *p_data;
@@ -193,9 +197,6 @@ prepare_print_master (GtkWidget *print_dlg,
   print_context =
     gnome_print_master_get_context (print_master);
 
-  def_font = gnome_font_new_closest  ("times", GNOME_FONT_BOOK, 0, 10);
-  gnome_print_setfont (print_context, def_font);
-
   gnome_print_dialog_get_copies (GPD (print_dlg), &copies, &collate);
   range = gnome_print_dialog_get_range_page (GPD (print_dlg), &from,
 					     &to);
@@ -260,22 +261,13 @@ static void
 print_dlg_clicked_cb (GtkWidget *print_dlg, gint button,
 		      ViewerData *viewer_data)
 {
-  gboolean destroy_dlg;
+  if (button == GNOME_PRINT_PREVIEW
+      || button == GNOME_PRINT_PRINT)
+    print_or_preview (print_dlg, viewer_data, button);
 
-  destroy_dlg = TRUE;
-
-  switch (button)
-    {
-    case GNOME_PRINT_PREVIEW:
-      destroy_dlg = FALSE;
-    case GNOME_PRINT_PRINT:
-      print_or_preview (print_dlg, viewer_data, button);
-      break;
-    case GNOME_PRINT_CANCEL:
-    }
-
-  if (destroy_dlg)
-    gtk_widget_destroy (print_dlg);
+  if (button == GNOME_PRINT_PRINT
+      || button == GNOME_PRINT_CANCEL)
+      gtk_widget_destroy (print_dlg);
 }
 
 void
