@@ -97,6 +97,8 @@ struct _OutputData
 #define MAX_PLIST 8
 static gchar *lpc_command = NULL;
 static gchar *lpstat_command = NULL;
+static gboolean commands_found = FALSE;
+static gboolean commands_message_shown = FALSE;
 
 /* Do various tests to determine how to get the list of printers.
    There are so many veriants of the lpr system... */
@@ -205,31 +207,41 @@ test_lpstat (gchar *lpstat)
   return ret_code;
 }
 
-static gboolean
-ensure_commands ()
+static void
+ensure_commands (ViewerData *viewer_data)
 {
-  gboolean ret_code;
   gchar *lpc, *lpstat;
   
-  if (lpc_command || lpstat_command)
-    ret_code = TRUE;
-  else
+  if (!commands_found)
     {
       lpc = where_is ("lpc");
       lpstat = where_is ("lpstat");
-         
+
       if (lpc)
-	ret_code = test_lpc (lpc);
-      else if (lpstat)
-	ret_code = test_lpstat (lpstat);
-      else
-	ret_code = FALSE;
+	commands_found = test_lpc (lpc);
+      if (lpstat)
+	commands_found = (test_lpstat (lpstat) || commands_found);
 
       g_free (lpc);
       g_free (lpstat);
-    }
 
-  return ret_code;
+      if (!commands_found
+          && !commands_message_shown)
+        {
+          display_failure (viewer_data->viewer_window,
+                           _("This is weird..."),
+                           _("I was not able to determine how to work\n"
+                             "with your printing system appropriately.\n\n"
+                             "Please have your administrator verify whether\n"
+                             "a descent printing system is installed.\n"
+                             "If this is so, there must be a bug in\n"
+                             "ghfaxviewer.\n"
+                             "In this case, please fill a bug report\n"
+                             "and send it to halifax-bugs@gnu.org."),
+                           _("I promise!"));
+          commands_message_shown = TRUE;
+        }
+    }
 }
 
 static int
@@ -359,7 +371,7 @@ make_printer_menu (PrintData *print_data)
   PList *plist, *cur_printer;
   
   plist = get_printers ();
-  
+
   if (plist)
     {
       menu = gtk_menu_new ();
@@ -367,7 +379,7 @@ make_printer_menu (PrintData *print_data)
       
       if (cur_printer->active)
 	print_data->printer = cur_printer->name;
-      
+
       while (cur_printer->active)
 	{
 	  menuitem = gtk_menu_item_new_with_label (cur_printer->name);
@@ -1083,23 +1095,7 @@ print_cb (GtkWidget *widget, ViewerData *viewer_data)
 {
   DialogWindow *print_dlg;
 
-  if (ensure_commands ())
-    {
-      print_dlg = print_dialog (viewer_data);
-      dialog_window_show (print_dlg, GTK_WINDOW (viewer_data->viewer_window));
-    }
-  else
-    {
-      display_failure (viewer_data->viewer_window,
-		       _("This is weird..."),
-		       _("I was not able to determine how to work\n"
-			 "with your printing system appropriately.\n\n"
-			 "Please have your administrator verify if\n"
-			 "a descent printing system is installed.\n"
-			 "If this is so, there must be a bug in\n"
-			 "ghfaxviewer.\n"
-			 "In this case, please fill a bug report\n"
-			 "and send it to halifax-bugs@gnu.org."),
-		       _("I promise!"));
-    }
+  ensure_commands (viewer_data);
+  print_dlg = print_dialog (viewer_data);
+  dialog_window_show (print_dlg, GTK_WINDOW (viewer_data->viewer_window));
 }
