@@ -318,7 +318,7 @@ fill_index (FaxPage *fax_page)
     {
       if (!is_open && *char_ptr) 
 	{
-	  index = g_slist_append (index, char_ptr);
+	  index = g_slist_prepend (index, char_ptr);
 	  is_open = TRUE;
 
 	  if (progress_func
@@ -336,7 +336,8 @@ fill_index (FaxPage *fax_page)
 	
       char_ptr++;
     }
-  
+
+  index = g_slist_reverse(index);
   fax_page->image_index = index;
 }
 
